EnrolledService

Struct EnrolledService 

pub struct EnrolledService {
    pub cloud_product: Option<String>,
    pub enrollment_level: Option<String>,
}
Represents the enrollment of a cloud resource into a specific service.

This type is not used in any activity, and only used as part of another schema.

Fields

cloud_product: Option<String>

The product for which Access Approval will be enrolled. Allowed values are listed below (case-sensitive):

  1. all
  2. appengine.googleapis.com
  3. bigquery.googleapis.com
  4. bigtable.googleapis.com
  5. cloudkms.googleapis.com
  6. compute.googleapis.com
  7. dataflow.googleapis.com
  8. iam.googleapis.com
  9. pubsub.googleapis.com
  10. storage.googleapis.com
    enrollment_level: Option<String>

    The enrollment level of the service.

    Trait Implementations

    Source

    impl Clone for EnrolledService

    Source

    fn clone(&self) -> EnrolledService

    Returns a duplicate of the value. Read more
    1.0.0 (const: unstable) · Source

    fn clone_from(&mut self, source: &Self)

    Performs copy-assignment from source. Read more
    Source

    impl Debug for EnrolledService

    Source

    fn fmt(&self, f: &mut Formatter<'_>) -> Result

    Formats the value using the given formatter. Read more
    Source

    impl Default for EnrolledService

    Source

    fn default() -> EnrolledService

    Returns the “default value” for a type. Read more
    Source

    impl<'de> Deserialize<'de> for EnrolledService

    Source

    fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>
    where __D: Deserializer<'de>,

    Deserialize this value from the given Serde deserializer. Read more
    Source

    impl Part for EnrolledService

    Source

    impl Serialize for EnrolledService

    Source

    fn serialize<__S>(&self, __serializer: __S) -> Result<__S::Ok, __S::Error>
    where __S: Serializer,

    Serialize this value into the given Serde serializer. Read more

    Auto Trait Implementations

    Blanket Implementations

    Source

    impl<T> Any for T
    where T: 'static + ?Sized,

    Source

    fn type_id(&self) -> TypeId

    Gets the TypeId of self. Read more
    Source

    impl<T> Borrow<T> for T
    where T: ?Sized,

    Source

    fn borrow(&self) -> &T

    Immutably borrows from an owned value. Read more
    Source

    impl<T> BorrowMut<T> for T
    where T: ?Sized,

    Source

    fn borrow_mut(&mut self) -> &mut T

    Mutably borrows from an owned value. Read more
    Source

    impl<T> CloneToUninit for T
    where T: Clone,

    Source

    unsafe fn clone_to_uninit(&self, dest: *mut u8)

    🔬This is a nightly-only experimental API. (clone_to_uninit)
    Performs copy-assignment from self to dest. Read more
    Source

    impl<T> DeserializeOwned for T
    where T: for<'de> Deserialize<'de>,

    Source

    impl<T> From<T> for T

    Source

    fn from(t: T) -> T

    Returns the argument unchanged.

    Source

    impl<T> Instrument for T

    Source

    fn instrument(self, span: Span) -> Instrumented<Self>

    Instruments this type with the provided Span, returning an Instrumented wrapper. Read more
    Source

    fn in_current_span(self) -> Instrumented<Self>

    Instruments this type with the current Span, returning an Instrumented wrapper. Read more
    Source

    impl<T, U> Into<U> for T
    where U: From<T>,

    Source

    fn into(self) -> U

    Calls U::from(self).

    That is, this conversion is whatever the implementation of From<T> for U chooses to do.

    Source

    impl<T> ToOwned for T
    where T: Clone,

    Source

    type Owned = T

    The resulting type after obtaining ownership.
    Source

    fn to_owned(&self) -> T

    Creates owned data from borrowed data, usually by cloning. Read more
    Source

    fn clone_into(&self, target: &mut T)

    Uses borrowed data to replace owned data, usually by cloning. Read more
    Source

    impl<T, U> TryFrom<U> for T
    where U: Into<T>,

    Source

    type Error = Infallible

    The type returned in the event of a conversion error.
    Source

    fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

    Performs the conversion.
    Source

    impl<T, U> TryInto<U> for T
    where U: TryFrom<T>,

    Source

    type Error = <U as TryFrom<T>>::Error

    The type returned in the event of a conversion error.
    Source

    fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

    Performs the conversion.
    Source

    impl<T> WithSubscriber for T

    Source

    fn with_subscriber<S>(self, subscriber: S) -> WithDispatch<Self>
    where S: Into<Dispatch>,

    Attaches the provided Subscriber to this type, returning a WithDispatch wrapper. Read more
    Source

    fn with_current_subscriber(self) -> WithDispatch<Self>

    Attaches the current default Subscriber to this type, returning a WithDispatch wrapper. Read more