pub struct ResourceProperties {
pub excludes_descendants: Option<bool>,
}Expand description
The properties associated with the resource of the request.
This type is not used in any activity, and only used as part of another schema.
Fields
excludes_descendants: Option<bool>Whether an approval will exclude the descendants of the resource being requested.