pub struct EnrolledService {
pub cloud_product: Option<String>,
pub enrollment_level: Option<String>,
}Expand description
Represents the enrollment of a cloud resource into a specific service.
This type is not used in any activity, and only used as part of another schema.
Fields
cloud_product: Option<String>The product for which Access Approval will be enrolled. Allowed values are listed below (case-sensitive):
- all
- appengine.googleapis.com
- bigquery.googleapis.com
- bigtable.googleapis.com
- cloudkms.googleapis.com
- compute.googleapis.com
- dataflow.googleapis.com
- iam.googleapis.com
- pubsub.googleapis.com
- storage.googleapis.com
enrollment_level: Option<String>The enrollment level of the service.